Name:		blender
Version:	2.65a
Release:	%mkrel 5
Summary:	A fully functional 3D modeling/rendering/animation package
Group:		Graphics/3D
Source0:	http://download.blender.org/source/blender-%{version}.tar.gz
Patch0:		blender-2.65-localedir.patch
Patch1:		blender-2.60-error-when-missing-sse.patch
Patch2:		blender-2.58-static-lib.patch
Patch3:		blender-2.65-openjpeg_stdbool.patch
# Patch submitted upstream - Blender Patches item #19234,
Patch6:         blender-2.64-uninit-var.patch
Patch7:		blender-2.65-link.patch
Patch8:		blender-2.65-str-fmt.patch
URL:		http://www.blender.org/
License:	GPLv2+
BuildRequires:	cmake >= 2.8
BuildRequires:	ffmpeg-devel
BuildRequires:	glew-devel
BuildRequires:	OpenEXR-devel
BuildRequires:	SDL-devel
BuildRequires:	libx11-devel
BuildRequires:	libxi-devel
BuildRequires:	freetype2-devel
BuildRequires:	libgomp-devel
BuildRequires:	jpeg-devel
BuildRequires:	png-devel
BuildRequires:	openjpeg-devel
BuildRequires:	openal-devel
BuildRequires:	libsamplerate-devel
BuildRequires:	sndfile-devel
BuildRequires:	libjack-devel
BuildRequires:	tiff-devel
BuildRequires:	fftw3-devel
BuildRequires:	python3-devel >= 3.2
BuildRequires:	boost-devel
BuildRequires:	openimageio-devel
Buildrequires:	opencolorio-devel
Requires:	python(abi) >= 3.2
Requires(post,preun): GConf2

%description
Blender is the in-house software of a high quality animation studio.
It has proven to be an extremely fast and versatile design instrument.
The software has a personal touch, offering a unique approach to the
world of three dimensions. Blender can be used to create TV
commercials, to make technical visualizations or business graphics, to
do some morphing, or to design user interfaces. Developers can easily
build and manage complex environments. The renderer is versatile and
extremely fast. All basic animation principles (curves and keys) are
implemented.

%prep
%setup -qn %{name}-%{version}
%patch0 -p1 -b .localedir
%patch1 -p0 -b .sse
%patch2 -p0 -b .static
%patch3 -p1 -b .bool
%patch6 -p0
%patch7 -p0
%patch8 -p0

%build
%ifarch %{ix86}
# build non-sse flavour
%cmake -DWITH_INSTALL_PORTABLE=OFF -DWITH_PLAYER=ON \
	-DWITH_PYTHON=ON -DWITH_PYTHON_INSTALL=OFF \
	-DPYTHON_VERSION=%{py3ver} -DWITH_BUILTIN_GLEW=OFF \
	-DWITH_CODEC_FFMPEG=ON -DWITH_CODEC_SNDFILE=ON \
	-DWITH_RAYOPTIMIZATION=OFF
%make
cd ..
mv build non-sse
%endif

#build sse flavour
%cmake -DWITH_INSTALL_PORTABLE=OFF -DWITH_PLAYER=ON \
	-DWITH_PYTHON=ON -DWITH_PYTHON_INSTALL=OFF \
	-DPYTHON_VERSION=%{py3ver} -DWITH_BUILTIN_GLEW=OFF \
	-DWITH_CODEC_FFMPEG=ON -DWITH_CODEC_SNDFILE=ON \
%ifarch %{ix86}
	-DSUPPORT_SSE2_BUILD=OFF \
%endif
	-DWITH_RAYOPTIMIZATION=ON
%make

%install
#install sse flavour
%makeinstall_std -C build

# Install hicolor icons.
for i in 16x16 22x22 32x32 48x48 256x256 ; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}/apps
  install -pm 0644 release/freedesktop/icons/${i}/apps/%{name}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${i}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -pm 0644 release/freedesktop/icons/scalable/apps/%{name}.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%ifarch %{ix86}
mv %buildroot%_bindir/%name %buildroot%_bindir/%name.sse

#install non-sse flavour
rm -fr build
mv non-sse build
%makeinstall_std -C build
mv %buildroot%_bindir/%name %buildroot%_bindir/%name.nonsse

# install wrapper
cat >> %{buildroot}%{_bindir}/blender <<EOF 
if [ -e /proc/cpuinfo ]; then
	SSE="\`cat /proc/cpuinfo | grep flags | grep sse\`"
fi

if [ "x\$SSE" == x ]; then
	%{_bindir}/%{name}.nonsse "\$@"
else
	%{_bindir}/%{name}.sse "\$@"
fi
EOF
chmod 0755 %{buildroot}%{_bindir}/blender
%endif

sed -i -e 's,#!/usr/bin/python,#!/usr/bin/python3,' %{buildroot}%{_bindir}/blender-thumbnailer.py %{buildroot}%{_datadir}/%{name}/*/scripts/modules/blend_render_info.py

%find_lang %name

%clean
rm -rf %{buildroot}

%post
if [ -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type boolean --set /desktop/gnome/thumbnailers/application@x-blender/enable true
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --type string --set /desktop/gnome/thumbnailers/application@x-blender/command "blender-thumbnailer.py %u %o"
fi

%preun
if [ "$1" = "0" -a -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/enable
   %{_gconftool_bin} --direct --config-source xml:readwrite:%{_sysconfdir}/gconf/gconf.xml.defaults --unset /desktop/gnome/thumbnailers/application@x-blender/command
fi

%files -f %name.lang
%doc release/text/*
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}
%{_mandir}/man1/%{name}.1.*
%{_iconsdir}/hicolor/*/apps/%{name}.*


%changelog

* Thu Apr 11 2013 barjac <barjac> 2.65a-5.mga3
+ Revision: 409767
- rebuild for boost-1.53

* Fri Jan 11 2013 umeabot <umeabot> 2.65a-4.mga3
+ Revision: 346914
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 2.65a-3.mga3
+ Revision: 341590
- rebuild for new ffmpeg

* Fri Dec 21 2012 cjw <cjw> 2.65a-2.mga3
+ Revision: 333650
- fix hardcoding of languages file location in patch0 that caused blender to crash at startup (mga #8394)

* Fri Dec 21 2012 fwang <fwang> 2.65a-1.mga3
+ Revision: 333544
- new version 2.65a

* Thu Dec 20 2012 fwang <fwang> 2.65-3.mga3
+ Revision: 332972
- rebuild for new boost

* Wed Dec 12 2012 fwang <fwang> 2.65-2.mga3
+ Revision: 329934
- br fftw3

* Wed Dec 12 2012 fwang <fwang> 2.65-1.mga3
+ Revision: 329929
- move languages file into datadir
- new version 2.65

* Sun Dec 02 2012 fwang <fwang> 2.64a-5.mga3
+ Revision: 325003
- rebuild for new openexr

* Sun Nov 11 2012 fwang <fwang> 2.64a-4.mga3
+ Revision: 316919
- br jack (bug#7952)

* Mon Oct 15 2012 fwang <fwang> 2.64a-3.mga3
+ Revision: 306643
- br opencolorio

* Wed Oct 10 2012 fwang <fwang> 2.64a-2.mga3
+ Revision: 304048
- drop support on sse2 in x86 build

* Wed Oct 10 2012 fwang <fwang> 2.64a-1.mga3
+ Revision: 304041
- new version 2.64a

* Sun Oct 07 2012 fwang <fwang> 2.64-3.mga3
+ Revision: 303270
- rebuild for new openjpeg

* Sun Oct 07 2012 fwang <fwang> 2.64-2.mga3
+ Revision: 303164
- try to build ffmpeg engine
- fix stf fmt
- fix str fmt
- fix str fmt
- fix stf fmt
- drop old tarball
- new version 2.64

* Sat Sep 29 2012 fwang <fwang> 2.63a-7.mga3
+ Revision: 300322
- specify py3ver
- update rpm group
- rebuild for new py3.3

* Tue Aug 21 2012 fwang <fwang> 2.63a-6.mga3
+ Revision: 282896
- rebuild for new glew

* Tue Jul 31 2012 fwang <fwang> 2.63a-5.mga3
+ Revision: 276847
- add upstream patch to build with latest boost
- rebuild for new glew

* Wed May 30 2012 fwang <fwang> 2.63a-4.mga3
+ Revision: 249541
- rebuild for new boost

* Mon May 28 2012 fwang <fwang> 2.63a-3.mga3
+ Revision: 247831
- try do not promote ffmpeg now, as it is too new
- apply patch
- fix build with latest ffmpeg headers
- more static lib build

* Mon May 28 2012 fwang <fwang> 2.63a-2.mga3
+ Revision: 247768
- fix build
- br openimageio for cycle engine

* Fri May 11 2012 fwang <fwang> 2.63a-1.mga2
+ Revision: 235264
- new version 2.63a

* Fri Apr 27 2012 fwang <fwang> 2.63-1.mga2
+ Revision: 233462
- SILEN: build correctly
- new version 2.63

* Thu Apr 12 2012 fwang <fwang> 2.62-2.mga2
+ Revision: 230392
- add fedora patch to build with latest openjpeg
- rebuild for new openjpeg

* Fri Feb 17 2012 fwang <fwang> 2.62-1.mga2
+ Revision: 210042
- br boost
- new version 2.62

* Fri Dec 23 2011 fwang <fwang> 2.61-2.mga2
+ Revision: 186497
- rebuild for new tiff

* Thu Dec 15 2011 fwang <fwang> 2.61-1.mga2
+ Revision: 181678
- new version 2.61

* Sun Nov 20 2011 fwang <fwang> 2.60a-3.mga2
+ Revision: 169769
- hardcode python3 usage

* Tue Oct 25 2011 fwang <fwang> 2.60a-2.mga2
+ Revision: 158008
- requires python3

* Tue Oct 25 2011 fwang <fwang> 2.60a-1.mga2
+ Revision: 157935
- new version 2.60a

* Thu Oct 20 2011 fwang <fwang> 2.60-1.mga2
+ Revision: 156766
- new version 2.60

* Fri Oct 07 2011 fwang <fwang> 2.59-5.mga2
+ Revision: 152638
- rebuild for new openjpeg

* Fri Oct 07 2011 fwang <fwang> 2.59-4.mga2
+ Revision: 152604
- rebuild for new openjpeg

* Mon Oct 03 2011 fwang <fwang> 2.59-3.mga2
+ Revision: 151161
- rebuild for new glew

* Mon Sep 12 2011 fwang <fwang> 2.59-2.mga2
+ Revision: 142630
- rebuild for new libpng
- new version 2.59
- add req for scriptles

* Sat Jul 09 2011 fwang <fwang> 2.58a-1.mga2
+ Revision: 120831
- new version 2.58a

* Tue Jun 28 2011 fwang <fwang> 2.58-1.mga2
+ Revision: 115153
- new version 2.58 (python3.2 based)

* Mon May 30 2011 pterjan <pterjan> 2.49b-10.mga1
+ Revision: 100764
- Rebuild with fixed mkrel

* Sun May 29 2011 tmb <tmb> 2.49b-9.mga1.
+ Revision: 100733
- bump rel for missing packages

  + dmorgan <dmorgan>
    - Revert to blender 2.49b

* Tue May 17 2011 dmorgan <dmorgan> 2.57b-3.mga1
+ Revision: 99512
- New version ( from mandriva )

* Mon May 09 2011 ahmad <ahmad> 2.49b-8.mga1
+ Revision: 96662
- Drop BR esound-devel, phasing out esound from the distro

* Sun Mar 27 2011 blino <blino> 2.49b-7.mga1
+ Revision: 78147
- really fix printf format for SCA_ExpressionController.cpp (from upstream SVN)
- use _real_vendor macro for desktop files naming
- remove old distro name and version checks
- remove unused python24 patch
- remove old version checks, mime types and menus
- imported package blender


* Sun Aug 15 2010 Funda Wang <fwang@mandriva.org> 2.49b-6mdv2011.0
+ Revision: 569888
- rebuild for new gettext

  + Ahmad Samir <ahmadsamir@mandriva.org>
    - rebuild for new gettext

* Mon May 17 2010 Giuseppe Ghibò <ghibo@mandriva.com> 2.49b-4mdv2010.1
+ Revision: 544918
- Bump release.

* Thu May 13 2010 Giuseppe Ghibò <ghibo@mandriva.com> 2.49b-3mdv2010.1
+ Revision: 544705
- Update icons (fix bug #59259).

  + Funda Wang <fwang@mandriva.org>
    - simplify mimelnk creation
    - add really xdg mime type for all distros
    - use standard mimelnk in < 200900 with standard KDE3
    - use opt mimelnk in 200900 and 200910 with opt KDE3

* Thu Feb 25 2010 Funda Wang <fwang@mandriva.org> 2.49b-2mdv2010.1
+ Revision: 511288
- use find_lang

  + Giuseppe Ghibò <ghibo@mandriva.com>
    - make tiff-devel BuildRequires conditional.
    - Don't use yet cmake for 2.4X series building (scons is still the preferred method...).
    - Increase max threads to 64 (it's not rare to have configuration like a quad-exacore server 7760, for a total of 24core and 48 h-threads).
    - Merged blender-2.49b spec release from www.joeghi.com/blender:
    - Update to r23322 for release 2.49b.
    - Update to r21165 (fix some bug in sequencer).
    - Don't Require yafray explicitely anymore (suggests instead yafaray).
    - Fixed wrapper against external scripts.
    - Update to r20988 for release 2.49a.
    - Rebuilt Patch10, Patch19 for fuzziness.
    - Rebuilt Patch17 (changelog).
    - Removed Patch4 (quicktime, unsupported).
    - Removed Patch45 (merged upstream).
    - Added Patch45 (wformat, avoid format not a string literal error).
    - Update to r20695 for various bugfixing.
    - Update icon set.
    - Rebuilt Patch41.
    - New release: 2.49 final.
    - Use r20529 source from SVN to fix A0 renderer error.
    - Removed Patch0 (openal, unused).
    - Removed Patch14 (alut, alut library no longer used).
    - Removed Patch42 (str, merged upstream).
    - Rebuilt Patch39 (sconsnew).
    - Rebuilt Patch22 (bug BL#6811).
    - Added Patch45 (bug BL#18847, material): adds Anisotropy, Mirr Threshold and Trans Threshold to python API calls.

* Sat Feb 06 2010 Funda Wang <fwang@mandriva.org> 2.49b-1mdv2010.1
+ Revision: 501423
- BR libgomp
- more unused patches dropped
- drop old scons stuffs
- fix typo
- add missing patch
- update file list
- build sse version only in ix86
- build with cmake
- fix large file patch
- rediff lib64 patch
- pt_BR fix is not needed
- rediff maxthreads patch
- rediff O3 patch
- New version 2.49b

* Mon Jan 11 2010 Oden Eriksson <oeriksson@mandriva.com> 2.48a-12mdv2010.1
+ Revision: 489740
- rebuilt against libjpeg v8

* Sun Jan 10 2010 Oden Eriksson <oeriksson@mandriva.com> 2.48a-11mdv2010.1
+ Revision: 488742
- rebuilt against libjpeg v8

* Thu Sep 24 2009 Olivier Blin <oblin@mandriva.com> 2.48a-10mdv2010.0
+ Revision: 448196
- don't use arch specific compile flags without proper ifarch, that's broken (from Arnaud Patard)

* Tue Sep 01 2009 Oden Eriksson <oeriksson@mandriva.com> 2.48a-9mdv2010.0
+ Revision: 423715
- fix spooky build stuff...
- fix deps (tiff-devel)
- rebuild

* Fri Apr 10 2009 Giuseppe Ghibò <ghibo@mandriva.com> 2.48a-8mdv2009.1
+ Revision: 365736
- Increase max threads # to 32 (Nehalem CPU supports HT again...).

* Wed Apr 08 2009 Giuseppe Ghibò <ghibo@mandriva.com> 2.48a-7mdv2009.1
+ Revision: 365080
- Fix maxthreads patch (according to Campbell suggestion on RE_MAX_THREAD).

* Sun Mar 15 2009 Giuseppe Ghibò <ghibo@mandriva.com> 2.48a-6mdv2009.1
+ Revision: 355350
- Conditional description.

  + Oden Eriksson <oeriksson@mandriva.com>
    - P43: security fix for CVE-2008-4863

* Thu Jan 22 2009 Funda Wang <fwang@mandriva.org> 2.48a-4mdv2009.1
+ Revision: 332413
- fix str fmt
- rediff deinterlace patch
- fix patch10

  + Michael Scherer <misc@mandriva.org>
    - fix patch 22, too fuzzy
    - fix patch 10 , too fuzzy

* Tue Dec 09 2008 Adam Williamson <awilliamson@mandriva.org> 2.48a-3mdv2009.1
+ Revision: 312121
- rebuild for new libftgl major

  + Giuseppe Ghibò <ghibo@mandriva.com>
    - In 2009.0 the place for .desktop files become /opt/kde3/share/mimelnk
      instead of /usr/share/mimelnk. Added a conditional for this.
    - Add conditional build flag for Adam legalese patch.
    - Add bool support for the redcode camera.
    - Rebuild Patch1 (ffmpeg)
    - Rebuild Patch13 (python 2.5).
    - Rebuild Patch17 (changelog).
    - Use svn 2.48a bz2 tarball.
    - Removed Patch7 (varuninitial), code moved.
    - Removed Patch35 (glext_undef).
    - Removed mlcd4 unused conditional flag.
    - Tuning flags.
    - Add yasm in BuildRequires.

* Tue Nov 04 2008 Funda Wang <fwang@mandriva.org> 2.48a-1mdv2009.1
+ Revision: 299815
- New version 2.48a
- drop old patches, rediff some patches

* Mon Sep 29 2008 Adam Williamson <awilliamson@mandriva.org> 2.47-2mdv2009.0
+ Revision: 289913
- add note on legal issues to description
- add legal.patch to disable patent-restricted bits of internal ffmpeg build
- add cve-2008-1103-1.patch (from Fedora) to fix CVE-2008-1103-1 (#44196)

  + Giuseppe Ghibò <ghibo@mandriva.com>
    - Temporary disable glew-devel in BuildRequires (buildsys broken).

* Fri Aug 15 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.47-1mdv2009.0
+ Revision: 272254
- Release 2.47.
- Removed Patches 40-48 (merged upstream).
- Removed Patch35 (unneeded, now using glew library).
- Added glew-devel to BuildRequires.
- Provide internal x-blender.desktop in mimelnk tree because version
  in kdelibs-common package is broken.

* Sun Jun 29 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.46-3mdv2009.0
+ Revision: 230063
- Use OpenEXR-devel >= 1.6.1 in BuildRequires, otherwise links againsts the
  older OpenEXR 1.4.

* Sun Jun 29 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.46-2mdv2009.0
+ Revision: 230056
- Use internal ffmpeg instead of system-wide one as system-wide is broken
  with sequencer (imported avis are left blank).
- Added Patch41 (Blender crashes when changing Scenes on Sequencer`s Strips BL#11745)
- Added Patch42 (Fix for bug BL#11758: crash cancelling hair softbody bake,
  fix for bug BL#11966: crash in hair softbody with hair amount 0).
- Added Patch44 (Bug BL#12106: Memory leak in sequencer (>10MB/frame)).
- Added Patch45 (Bug BL#12473: crash converting old particle system from a linked file).
- Added Patch46 (Bug BL#13311: video_stream NULL when writing ffmpeg).
- Added Patch47 (Bug BL#13649: segmentation fault when deleting object).
- Added Patch48 (Bug BL#13666: added missing #include <stdio.h> in KX_RayCast.cpp).
- Rebuild Patch38 for ffmpeg lib.
- Release 2.46 final.
- Added Patch40 to fix problem in sequencer ("Translate" stops working when offset > image size, BL#11750).

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas
    - remove support for distro < 2006.1

* Fri May 02 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.46-0.20080502.1mdv2009.0
+ Revision: 200031
- Added Patch38 for newer ffmpeg.
- Added Patch39 for supporting scons 0.92.2.
- More conditional builds.
- Removed -floop-optimize2 (not supported anymore on gcc 4.2.X).
- Added python-scons to BuildRequires.
- svn 20080425.
- Add support for compiling with system wide-bullet library (don't work yet).
- Added Patch37 to get the 4x4 matrix determinant computation faster.
- Reworked Patch35 (glext).
- Added -floop-optimize2 to optimization flags.

* Mon Apr 14 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.46-0.20080414.1mdv2009.0
+ Revision: 192678
- svn 2.46 of 20080414.
- Release 2.46-20080410.
- Removed Patch5 (libtiff, merged upstream)
- Removed Patch11 (morethreads, merged upstream).
- Removed Patch8 (yafray64, merged upstream).
- Removed Patch 9 (yafray-ncpus).
- Removed Patch16 (avclose, merged upstream).
- Removed Patch25-33 (merged upstream).
- Reworked Patch18 (zero threads safety).
- Reworked Patch22 (6811, partially merged upstream, except for verse).
- Add Patch34 for deinterlacing.
- Add Patch35 for fixing segfault on 64bit archs with nVidia cards (bug BL#7113)
- Add Patch36 for adding a new display mode to the outliner (bug BL#8195).

* Thu Mar 20 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.45-7mdv2008.1
+ Revision: 189280
- Add Patch35 to fix GameEngine crashing under Nvidia 64bit cards (bug BL#7113).

* Sun Feb 24 2008 Giuseppe Ghibò <ghibo@mandriva.com> 2.45-6mdv2008.1
+ Revision: 174343
- Remove unused patches.
- Rebuild against latest ffmpeg.
- Added Patch for deinterlacing in nodes (BL#7970).

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Sun Dec 09 2007 Funda Wang <fwang@mandriva.org> 2.45-5mdv2008.1
+ Revision: 116694
- drop old menu

  + Thierry Vignaud <tv@mandriva.org>
    - buildrequires X11-devel instead of XFree86-devel

* Mon Nov 12 2007 Funda Wang <fwang@mandriva.org> 2.45-4mdv2008.1
+ Revision: 108217
- rebuild for new gettext

* Thu Nov 01 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.45-3mdv2008.1
+ Revision: 104704
- Add Patch24 (from Humfred Fr. <humfred.fr@gmail.com>) for fixing bug #34942.
- Add Patch25 for fixing bug BL#7033 (from svn-stable r12026).
- Add Patch26 to add in python version info (from svn-stable r12027).
- Add Patch27 for fixing fuildsimCopyMesh (from svn-stable r12031).
- Add Patch28 for fixing bug BL#7310 about FluidSim Domain/Fluid (from svn-stable r12033).
- Add Patch29 for avoiding crash on startup when importing sys in python (from svn-stable r12051).
- Add Patch30 for having a function defined only when yafray is enabled (from svn-stable 12055).
- Add Patch31 for fixing bug BL#7334 (from svn-stable 12056).
- Add Patch32, Patch33 for purging compiler warnings (from svn-stable 12077, 12127).

* Thu Sep 13 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.45-2mdv2008.0
+ Revision: 85283
- Release: 2.45.

* Wed Sep 12 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.44-6.20070912.1mdv2008.0
+ Revision: 84787
- Updated to 2.44-stable svn-20070912.
- Updated logs in Patch17.

* Tue Sep 11 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.44-5.20070910.2mdv2008.0
+ Revision: 84327
- fix relver.
- Updated to 2.44-stable svn-20070910.
- Updated logs in Patch17.

* Sun Sep 09 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.44-4.20070826.2mdv2008.0
+ Revision: 83756
- Update to 2.44 stable 20070826.
- Fix Python patch (Patch13).
- Added Patch22 to fix blender bug #6811.
- Added Patch23 to allow more than 6 subsurf level from panel.
- Fix changelog.
- Added patch for blender bug 6811.
- Added verse binaries.
- Branch stable 2.44 of 20070724.
- Updated Patch17.

* Mon May 14 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.44-2mdv2008.0
+ Revision: 26720
- Added Patch21, for missed boxpack2d.py script (still needed by
  some other scripts).

* Sun May 13 2007 Giuseppe Ghibò <ghibo@mandriva.com> 1mdv2008.0-current
+ Revision: 26582
- Release: 2.44.
- Removed Patch15, now 64bit is officially supported.
- Enabled Verse.

* Sun May 13 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-4mdv2008.0
+ Revision: 26575
- Fixed Patch18 for zero threads (bug #30137).
- Added Patch19 to allow 16 threads.


* Wed Mar 14 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-3mdv2007.1
+ Revision: 143270
- Rebuilt against latest ffmpeg.
- Ensure Building with against ffmpeg containing the img_convert in the API.
- Added Patch18 to avoid yafray rendering with 0 threads.

* Sat Feb 17 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-1mdv2007.1
+ Revision: 122138
- Enabled smp for building.
- Rebuilt Patch7.
- Removed Patch12, merged upstream.
- Updated Source0.
- Removed old Sources from tree.
- 2.43 final.
- Added Patch17 for fixing ChangeLog.
- Readded Patch16.
- Added InitialPreference in .desktop files.
- 2.43-20070214 (>RC3).
- use %%{name} macro to allow future build with version in name.

* Thu Feb 08 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-0.20070207.2mdv2007.1
+ Revision: 117805
- Added Patch16 for fixing segfault in Image Browser.

* Wed Feb 07 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-0.20070207.1mdv2007.1
+ Revision: 117069
- 2.43-20070707 (RC3).

* Sun Jan 28 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-0.20070128.1mdv2007.1
+ Revision: 114624
- release cvs 20070128 (>2.43RC2).
- call executable with -w (bug #26454).
- fixed blenderplayer position to correctly save the runtime.

* Fri Jan 19 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-0.20070119.1mdv2007.1
+ Revision: 110976
- Release 20070119 from CVS.
- Added Patch15 for 64bit warning.

* Fri Jan 19 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-0.20070118.1mdv2007.1
+ Revision: 110554
- Release 20070118 from CVS.
- Removed Patch15 (no longer needed).

* Sun Jan 07 2007 Giuseppe Ghibò <ghibo@mandriva.com> 2.43-0.20070101.2mdv2007.1
+ Revision: 105281
- modified string size in Patch12 to 16 to preserve the ABI.
- conditional BuildRequires for freealut-devel.
- Release 20070101 from CVS (RC1).
- Rebuilt Patch2.
- Rebuilt Patch12.
- Added freealut to Buildrequires (from Jan Ciger).
- Reworked Patch13 and Patch14 (from Jan Ciger) and apply
  only for 2007.1 (since python-config command was
  not available into python 2.4 package).
- Added Patch15 for fixing buffer overflow over stronger
  optimization flags.

* Wed Aug 23 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.42a-3mdv2007.0
+ Revision: 57087
- Fixed buffer overflow of bug #24583.

* Thu Aug 10 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.42a-2mdv2007.0
+ Revision: 54796
- Added Patch11 for to allow more threads.

  + Olivier Blin <oblin@mandriva.com>
    - fix typo in wrapper script, when upgrading from a previous version

* Sun Jul 30 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.42a-1mdv2007.0
+ Revision: 42619
- Release 2.42a.

* Tue Jul 25 2006 Giuseppe Ghibò <ghibo@mandriva.com> 2.42-2mdv2007.0
+ Revision: 41974
- changed ffmpeg-devel BuildRequires to 0.4.9-1.pre1.
- added OpenEXR-devel to BuildRequires
- added version into ffmpeg-devel BuildRequires and
  conditional switch (for MDV2006, since older ffmpeg, the
  ffmpeg support will be disabled).
- set mode 644 for internal .py scripts.
- use %%update_desktop_database instead of %%clean_desktop_database
  in %%post.
- xdg menus.
- fixes to wrapper.
- disabled -ftree-vectorize from CFLAGS, CXXFLAGS as it doesn't give
  improvements in rendering time.
- clean CFLAGS, CXXFLAGS.
- correctly copy user-config.py.std to user-config.py
- fixed install path of blender.sse.
- fixed cp of blender.sse.
- added blender-2.42-buildfix.patch.
- Added Patch10 for fixing problems with -O3 optimization
- Added Patch9 for fixing problem with SMP and yafray.
- Improved regexp for blendernodri (thanks to blino).
- Readapted Patch2,3.
- Removed Patch4,6  (merged upstream).
- fix applying Patch9
- fix minimal number of cpus/threads when called yafray.
- Better patch for x86-64
- added patch for correctly searching yafray plugin
- Added Requires: libtiff (dinamically loaded).
- Added Patch5 for loading libtiff.so.3 instead of libtiff.so (avoid
  installation of libtiff devel package).
- Added Patch6 for fixing a missed header.
- Added Patch7 for fixing an unitialized variable.
- [$VER: 2.41-5mdv]
- Force calling yafray trough library and not trough XML file (Patch3) as
  XML doesn't work anymore with yafray > 0.07, and anyway plugin it's better.
- Added yafray in Requires.
- Quote \$@ in wrapper.
- Added blendernodri wrapper to avoid blender's UI flashing problems
  with some card under DRI (e.g. Matrox).
- Updated svg2obj python script to 0.47.

  + Helio Chissini de Castro <helio@mandriva.com>
    - Fixed the mess did on svn versus regular upload. We should take more care in
      further operations.
      * Seg Mai 22 2006 Giuseppe Ghib?\195?\178 <ghibo@mandriva.com> 2.41-3mdk
    - Stronger optimization with %%optflags (thanks to Pixel).
    - python-devel >= 2.4 in BuildRequires.
    - New wrapper. Blender plugins usually deal with a lot of tmp/inplace writing.
      So now user get their own .blender env created.
    - Fixed locale translations.
    - Fixed pt_BR potfile naming
    - New upstream release
    - Finally we have blender internationalized, ann compiling in x86_64
    - Physics engine ODE isn't compiling at this moment
    - blenderplayer was reenabled, so game on again :-)
    - Still fixing my mess
    - Fix my mess

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

* Fri Apr 14 2006 Giuseppe Ghib <ghibo@mandriva.com> 2.40-2mdk
- Added tiff-devel to BuildRequires.

* Wed Dec 28 2005 Olivier Blin <oblin@mandriva.com> 2.40-1mdk
- New release 2.40

* Thu Aug 04 2005 Gustavo Pichorim Boiko <boiko@mandriva.com> 2.37a-1mdk
- Updated to version 2.37a
- Added blenderplayer (the standalone game player)
- Added some default python scripts for importing and exporting
- Added localization files to the package. They were put into the main package
  because blender doesn't automatically choose the language in the interface.

* Fri Jun 03 2005 Olivier Blin <oblin@mandriva.com> 2.37-1mdk
- 2.37 : http://www.blender3d.org/cms/Blender_2_37.496.0.html

* Fri Dec 24 2004 Lenny Cartier <lenny@mandrakesoft.com> 2.36-1mdk
- 2.36

* Sun Dec 05 2004 Michael Scherer <misc@mandrake.org> 2.35-2mdk
- Rebuild for new python

* Tue Nov 16 2004 Olivier Blin <blino@mandrake.org> 2.35-1mdk
- 2.35 : http://www.blender3d.org/cms/Blender_2_35.482.0.html

* Sat Aug 07 2004 Olivier Blin <blino@mandrake.org> 2.34-1mdk
- 2.34 : http://www.blender3d.org/cms/Blender_2_34.319.0.html
- remove gcc/libstdc++ patches (fixed upstream)
- fix doc files list

* Thu Jun 24 2004 Olivier Blin <blino@mandrake.org> 2.33a-1mdk
- 2.33a (yeah, game engine is back)
- rediff Patch1
- more gcc 3.4 template fixes (Patch2)
- switch to scons build system

* Thu Jun 17 2004 Olivier Blin <blino@mandrake.org> 2.32-2mdk
- rebuilt for new libstdc++
- Added Patch0 to fix build with new libstdc++
- Added Patch1 to fix build with gcc 3.4

* Sat Apr 03 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 2.32-1mdk
- 2.32
- fix buildrequires (lib64..)
- don't bzip2 icons in src.rpm

